@@ -410,9 +410,12 @@ _INLINE_ __u32 ext2fs_swab32(__u32 val)
 #endif /* !_EXT2_HAVE_ASM_SWAB */
 
 #if !defined(_EXT2_HAVE_ASM_FINDBIT_)
+/* Use the prototype from builtin_ffs() */
+extern int ffs(unsigned int);
+
 _INLINE_ int ext2fs_find_first_bit_set(void * addr, unsigned size)
 {
-	char	*cp = (unsigned char *) addr;
+	unsigned char	*cp = (unsigned char *) addr;
 	int 	res = 0, d0;
 
 	if (!size)
