@@ -42,7 +42,6 @@ typedef struct {
 } CONFIG;
 
 #define MAX_TOKEN 511
-#define MAX_VAR_NAME MAX_TOKEN
 #define EOF -1
 
 CONFIG cf_options[] =
@@ -92,7 +91,6 @@ CONFIG cf_image[] =
      {cft_flag, "pause-after", NULL},
      {cft_strg, "pause-message", NULL},
      {cft_flag, "novideo", NULL},
-     {cft_strg, "sysmap", NULL},
      {cft_end, NULL, NULL}};
 
 static char flag_set;
@@ -103,7 +101,6 @@ static char *currp = NULL;
 static char *endp = NULL;
 static char *file_name = NULL;
 static CONFIG *curr_table = cf_options;
-static int ignore_entry;
 static jmp_buf env;
 
 static struct IMAGES {
@@ -434,12 +431,12 @@ static int cfg_reset ()
     curr_table = cf_options;
     for (walk = curr_table; walk->type != cft_end; walk++) {
 #if DEBUG
-        prom_printf("ItemA %s = %s\n", walk->name, walk->data);
+        prom_printf("ItemA %s = %s\n", walk->name, (char *)walk->data);
 #endif
         if (walk->data != NULL)
             walk->data = NULL;
 #if DEBUG
-        prom_printf("ItemB %s = %s\n\n", walk->name, walk->data);
+        prom_printf("ItemB %s = %s\n\n", walk->name, (char *)walk->data);
 #endif
     }
 
