@@ -27,6 +27,7 @@
 extern const struct fs_t	of_filesystem;
 extern const struct fs_t	of_net_filesystem;
 extern const struct fs_t	ext2_filesystem;
+extern const struct fs_t        swap_filesystem;
 //extern const struct fs_t	iso_filesystem;
 
 /* Configurable filesystems */
@@ -41,6 +42,7 @@ extern const struct fs_t        reiserfs_filesystem;
 
 /* Filesystem handlers yaboot knows about */
 static const struct fs_t *block_filesystems[] = {
+     &swap_filesystem,		/* swap signature checker */
      &ext2_filesystem,		/* ext2 */
 #ifdef CONFIG_FS_XFS
      &xfs_filesystem,                /* XFS */
@@ -56,12 +58,12 @@ const struct fs_t *fs_of = &of_filesystem;              /* needed by ISO9660 */
 const struct fs_t *fs_of_netboot = &of_net_filesystem;  /* needed by file.c */
 
 const struct fs_t *
-fs_open(struct boot_file_t *file, const char *dev_name,
-	struct partition_t *part, const char *file_name)
+fs_open(struct boot_file_t *file,
+	struct partition_t *part, struct boot_fspec_t *fspec)
 {
      const struct fs_t **fs;
      for (fs = block_filesystems; *fs; fs++)
-	  if ((fserrorno = (*fs)->open(file, dev_name, part, file_name)) != FILE_ERR_BAD_FSYS)
+	  if ((fserrorno = (*fs)->open(file, part, fspec)) != FILE_ERR_BAD_FSYS)
 	       break;
 
      return *fs;
